ziggy.GraphReduce

Package ziggy :: Package GraphReduce |
[hide private]
[frames] | no frames]

# Package GraphReduce

source code

Submodules | [hide private]
ziggy.GraphReduce.Degree_mapper: Created on Aug 25, 2010 ziggy.GraphReduce.Degree_reducer: Created on Aug 25, 2010 ziggy.GraphReduce.GraphLoader: Created on Aug 11, 2010 ziggy.GraphReduce.LostMass_mapper: Created on Aug 18, 2010 ziggy.GraphReduce.LostMass_reducer: Created on Aug 18, 2010 ziggy.GraphReduce.PBFS_mapper: Created on Aug 12, 2010 ziggy.GraphReduce.PBFS_reducer: Created on Aug 12, 2010 ziggy.GraphReduce.PageRank_mapper: Created on Aug 18, 2010 ziggy.GraphReduce.PageRank_reducer: Created on Aug 18, 2010 ziggy.GraphReduce.gr_link_analysis: Created on Aug 18, 2010 ziggy.GraphReduce.gr_path: Created on Aug 12, 2010 ziggy.GraphReduce.hadoop_config: Created on May 17, 2010 Generic configuration parameters for Hadoop-based python modules

Variables | [hide private]
| __package__ = `None`